pub struct DMSCRouter { /* private fields */ }Expand description
Router for managing API routes and matching requests to handlers.
This struct maintains a collection of routes and provides methods for adding routes, matching requests to handlers, and mounting routers with prefixes.
Implementations
Sourceimpl DMSCRouter
impl DMSCRouter
Sourceimpl DMSCRouter
impl DMSCRouter
Sourcepub fn get(&self, path: &str, handler: DMSCRouteHandler)
pub fn get(&self, path: &str, handler: DMSCRouteHandler)
Adds a GET route to the router.
Parameters
path: Path pattern for the routehandler: Request handler for the route
Sourcepub fn post(&self, path: &str, handler: DMSCRouteHandler)
pub fn post(&self, path: &str, handler: DMSCRouteHandler)
Adds a POST route to the router.
Parameters
path: Path pattern for the routehandler: Request handler for the route
Sourcepub fn put(&self, path: &str, handler: DMSCRouteHandler)
pub fn put(&self, path: &str, handler: DMSCRouteHandler)
Adds a PUT route to the router.
Parameters
path: Path pattern for the routehandler: Request handler for the route
Sourcepub fn delete(&self, path: &str, handler: DMSCRouteHandler)
pub fn delete(&self, path: &str, handler: DMSCRouteHandler)
Adds a DELETE route to the router.
Parameters
path: Path pattern for the routehandler: Request handler for the route
Sourcepub fn patch(&self, path: &str, handler: DMSCRouteHandler)
pub fn patch(&self, path: &str, handler: DMSCRouteHandler)
Adds a PATCH route to the router.
Parameters
path: Path pattern for the routehandler: Request handler for the route
Sourcepub fn options(&self, path: &str, handler: DMSCRouteHandler)
pub fn options(&self, path: &str, handler: DMSCRouteHandler)
Adds an OPTIONS route to the router.
Parameters
path: Path pattern for the routehandler: Request handler for the route
Sourcepub async fn route(
&self,
request: &DMSCGatewayRequest,
) -> DMSCResult<DMSCRouteHandler>
pub async fn route( &self, request: &DMSCGatewayRequest, ) -> DMSCResult<DMSCRouteHandler>
Finds a matching route for the given request.
This method checks the route cache first, then searches through registered routes to find a match. It returns the handler for the matching route, or an error if no route is found.
Parameters
request: The gateway request to find a route for
Returns
A DMSCResult<DMSCRouteHandler> with the matching handler, or an error if no route is found
Sourcepub fn mount(&self, prefix: &str, router: &DMSCRouter)
pub fn mount(&self, prefix: &str, router: &DMSCRouter)
Mounts another router’s routes with a prefix.
This method adds all routes from another router to this router, prepending the specified prefix to each route’s path.
Parameters
prefix: The prefix to prepend to all mounted routesrouter: The router to mount
Sourcepub fn clear_routes(&self)
pub fn clear_routes(&self)
Clears all routes from the router.
This method removes all routes from the router and clears the route cache.
Sourcepub fn route_count(&self) -> usize
pub fn route_count(&self) -> usize
Gets the number of routes registered in the router.
Returns
The number of routes registered in the router